==> hinemos_src-3.2.1.tar.gz: HinemosManager/src_notify/com/clustercontrol/notify/factory/SelectNotifyRelation.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.notify.factory;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.NotifyNotFoundException;
import com.clustercontrol.notify.bean.NotifyRelationInfo;
import com.clustercontrol.notify.ejb.entity.NotifyRelationInfoLocal;
import com.clustercontrol.notify.ejb.entity.NotifyRelationInfoUtil;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * システム通知情報を検索するクラスです。
 *
 * @version 2.1.0
 * @since 2.1.0
 */
public class SelectNotifyRelation {
	
	/** ログ出力のインスタンス。 */
	protected static Log m_log = LogFactory.getLog( SelectNotifyRelation.class );
	
	/**
	 * システム通知情報を返します。
	 * 
	 * @param notifyId 取得対象の通知ID
	 * @return システム通知情報
	 * @throws NamingException
	 * @throws NotifyNotFoundException 
	 */
	public Collection<NotifyRelationInfo>  getNotifyRelation(String notifyGroupId) throws NamingException, NotifyNotFoundException {
		
		ArrayList<NotifyRelationInfo> ret = new ArrayList<NotifyRelationInfo> ();
		Collection<NotifyRelationInfoLocal> notifies =  null;
		try {
			notifies = NotifyRelationInfoUtil.getLocalHome().findByNotifyGroupId(notifyGroupId);
		} catch (FinderException e){
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
			m_log.debug("getNotifyMap():" + e.getMessage());
			throw new NotifyNotFoundException(e.getMessage(),e);
		}
		
		Iterator<NotifyRelationInfoLocal> it = notifies.iterator();
		
		while(it.hasNext()){
			
			 NotifyRelationInfoLocal detailEjb =it.next();
			 
			 NotifyRelationInfo detail = new NotifyRelationInfo(
					 detailEjb.getNotifyGroupId(),
					 detailEjb.getNotifyId(),
					 detailEjb.getNotifyType(),
					 detailEjb.getNotifyFlg());
			 
			 ret.add(detail);
			 
		}
		return ret;
		
	}
	
	/**
	 * 引数で指定した通知IDを利用している通知グループIDを取得する。
	 * 
	 * @param notifyId
	 * @return 通知グループIDのリスト
	 * @throws FinderException
	 * @throws NamingException
	 */
	public ArrayList<String> getNotifyGroupIdBaseOnNotifyId(String notifyId) throws NotifyNotFoundException, NamingException{
		
		ArrayList<String> ret = new ArrayList<String>();
		Collection<NotifyRelationInfoLocal> relations;
		try {
			relations = NotifyRelationInfoUtil.getLocalHome().findByNotifyId(notifyId);
		} catch (FinderException e){
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
			m_log.debug("getNotifyGroupIdBaseOnNotifyId(String):" + e.getMessage());
			throw new NotifyNotFoundException(e.getMessage(),e);
		}
		
		Iterator<NotifyRelationInfoLocal> itr = relations.iterator();
		
		while(itr.hasNext()){
			
			NotifyRelationInfoLocal relation = itr.next();
			
			ret.add(relation.getNotifyGroupId());
			
		}
		
		return ret;
	}
	
}

==> hinemos_src-4.0.3.tar.gz: HinemosManager/src_notify/com/clustercontrol/notify/factory/SelectNotifyRelation.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.notify.factory;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.fault.NotifyNotFound;
import com.clustercontrol.notify.bean.NotifyRelationInfo;
import com.clustercontrol.notify.ejb.entity.NotifyRelationInfoLocal;
import com.clustercontrol.notify.ejb.entity.NotifyRelationInfoUtil;
import com.clustercontrol.util.apllog.AplLogger;

/**
 * システム通知情報を検索するクラスです。
 *
 * @version 2.1.0
 * @since 2.1.0
 */
public class SelectNotifyRelation {

	/** ログ出力のインスタンス。 */
	private static Log m_log = LogFactory.getLog( SelectNotifyRelation.class );

	/**
	 * システム通知情報を返します。
	 * 
	 * @param notifyId 取得対象の通知ID
	 * @return システム通知情報
	 * @throws NamingException
	 * @throws NotifyNotFound
	 */
	public ArrayList<NotifyRelationInfo> getNotifyRelation(String notifyGroupId) throws NamingException, NotifyNotFound {

		ArrayList<NotifyRelationInfo> ret = new ArrayList<NotifyRelationInfo> ();
		Collection<NotifyRelationInfoLocal> notifies =  null;
		try {
			notifies = NotifyRelationInfoUtil.getLocalHome().findByNotifyGroupId(notifyGroupId);
		} catch (FinderException e){
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
			m_log.debug("getNotifyMap():" + e.getMessage());
			throw new NotifyNotFound(e.getMessage(),e);
		}

		Iterator<NotifyRelationInfoLocal> it = notifies.iterator();

		while(it.hasNext()){

			NotifyRelationInfoLocal detailEjb =it.next();

			NotifyRelationInfo detail = new NotifyRelationInfo(
					detailEjb.getNotifyGroupId(),
					detailEjb.getNotifyId(),
					detailEjb.getNotifyType(),
					detailEjb.getNotifyFlg());

			ret.add(detail);

		}
		return ret;

	}

	/**
	 * 引数で指定した通知IDを利用している通知グループIDを取得する。
	 * 
	 * @param notifyId
	 * @return 通知グループIDのリスト
	 * @throws FinderException
	 * @throws NamingException
	 */
	public ArrayList<String> getNotifyGroupIdBaseOnNotifyId(String notifyId) throws NotifyNotFound, NamingException{

		ArrayList<String> ret = new ArrayList<String>();
		Collection<NotifyRelationInfoLocal> relations;
		try {
			relations = NotifyRelationInfoUtil.getLocalHome().findByNotifyId(notifyId);
		} catch (FinderException e){
			AplLogger apllog = new AplLogger("NOTIFY", "notify");
			m_log.debug("getNotifyGroupIdBaseOnNotifyId(String):" + e.getMessage());
			throw new NotifyNotFound(e.getMessage(),e);
		}

		Iterator<NotifyRelationInfoLocal> itr = relations.iterator();

		while(itr.hasNext()){

			NotifyRelationInfoLocal relation = itr.next();

			ret.add(relation.getNotifyGroupId());

		}

		return ret;
	}

}
